This is a demo code for Spatial Multi-View representation learning algorithm. Before you run the code, please make sure that you have stored your data in the Data folder.

To run the model for one time without interpretable mode, please use the following code
```
python main.py
```

To run the model for one time with interpretable mode, please use the following code
```
python main_interpretable.py
```

